@@ -3,7 +3,10 @@
 #' Plot a dotplot of Potential Scale Reduction Factor (Rhat), proposed by Gelman and Rubin (1992). The version from the second edition of Bayesian Data Analysis (Gelman, Carlin, Stein and Rubin) is used.
 #'
 #' Notice that at least two chains are required.
-#
+#'
+#' @references Fernández-i-Marín, Xavier (2016) ggmcmc: Analysis of MCMC Samples and Bayesian Inference. Journal of Statistical Software, 70(9), 1-20. doi:10.18637/jss.v070.i09
+#' @references Gelman, Carlin, Stern and Rubin (2003) Bayesian Data Analysis. 2nd edition. Chapman & Hall/CRC, Boca Raton.
+#' @references Gelman, A and Rubin, DB (1992) Inference from iterative simulation using multiple sequences, _Statistical Science_, *7*, 457-511.
 #' @param D Data frame whith the simulations
 #' @param family Name of the family of parameters to plot, as given by a character vector or a regular expression. A family of parameters is considered to be any group of parameters with the same name but different numerical value between square brackets (as beta[1], beta[2], etc).
 #' @param scaling Value of the upper limit for the x-axis. By default, it is 1.5, to help contextualization of the convergence. When 0 or NA, the axis are not scaled.
@@ -52,7 +55,7 @@ ggs_Rhat <- function(D, family=NA, scaling=1.5, greek=FALSE) {
   BW$Rhat[is.nan(BW$Rhat)] <- NA
   # Plot
   f <- ggplot(BW, aes(x=Rhat, y=Parameter)) + geom_point() +
-    xlab(expression(hat("R"))) + ggtitle("Potential Scale Reduction Factor")
+    xlab(expression(hat("R"))) + ggtitle("Potential Scale Reduction Factors")
   if (greek) {
     f <- f + scale_y_discrete(labels = parse(text = as.character(BW$Parameter)))
   }
