@@ -1,7 +1,8 @@
 #' Histograms of the paramters.
 #'
 #' Plot a histogram of each of the parameters. Histograms are plotted combining all chains for each parameter.
-#
+#'
+#' @references Fernández-i-Marín, Xavier (2016) ggmcmc: Analysis of MCMC Samples and Bayesian Inference. Journal of Statistical Software, 70(9), 1-20. doi:10.18637/jss.v070.i09
 #' @param D Data frame whith the simulations.
 #' @param family Name of the family of parameters to plot, as given by a character vector or a regular expression. A family of parameters is considered to be any group of parameters with the same name but different numerical value between square brackets (as beta[1], beta[2], etc). 
 #' @param bins integer indicating the total number of bins in which to divide the histogram. Defaults to 30, which is the same as geom_histogram()
@@ -19,11 +20,11 @@ ggs_histogram <- function(D, family=NA, bins=30, greek=FALSE) {
   # Manually generate the histogram by parameter, based on the total number of bins
   ds <- D %>%
     dplyr::group_by(Parameter) %>%
-    dplyr::do(calc_bin(.$value, bins))
+    dplyr::do(calc_bin(.$value, bins)) %>%
+    ungroup()
   dl <- as.numeric(table(ds$Parameter))
   # There may be cases of parameters with slightly different numbers of bins,
   # and therefore a Parameter-by-Parameter approach is needed
-  ds <- cbind(Parameter=gl_unq(attributes(D)$nParameters, dl, labels=levels(D$Parameter)), ds)
   # Plot
   f <- ggplot(ds, aes(x=x, y=count, width=width)) + 
     geom_bar(stat="identity", position="identity") +
